@@ -23,7 +23,7 @@ config = {
     'instance_tiddlers': get_tiddler_locations(store_contents, PACKAGE_NAME),
     'atom.default_filter': 'select=tag:!excludeLists;sort=-modified;limit=20',
     'atom.author_uri_map': '/profiles/%s',
-    'atom.hub': 'http://pubsubhubbub.appspot.com/publish',
+    'atom.hub': 'http://pubsubhubbub.appspot.com/',
     'beanstalk.listeners': ['tiddlywebplugins.dispatcher.listener', 'tiddlywebplugins.tiddlyspace.profiles'],
     'auth_systems': ['cookie_form', 'tiddlywebplugins.tiddlyspace.openid'],
     'bag_create_policy': 'ANY',
